@@ -22,27 +22,24 @@ from __future__ import absolute_import
 
 import calendar
 import datetime
-import json
 import os
 import re
-import socket
 from threading import local as Local
 
+import google.auth
+from google.protobuf import duration_pb2
 from google.protobuf import timestamp_pb2
-try:
-    from google.appengine.api import app_identity
-except ImportError:
-    app_identity = None
+import google_auth_httplib2
+
 try:
     import grpc
+    import google.auth.transport.grpc
 except ImportError:  # pragma: NO COVER
     grpc = None
+
+import httplib2
 import six
 from six.moves import http_client
-from six.moves import configparser
-
-from google.cloud.environment_vars import PROJECT
-from google.cloud.environment_vars import CREDENTIALS
 
 
 _NOW = datetime.datetime.utcnow  # To be replaced by tests.
@@ -168,139 +165,11 @@ def _ensure_tuple_or_list(arg_name, tuple_or_list):
     return list(tuple_or_list)
 
 
-def _app_engine_id():
-    """Gets the App Engine application ID if it can be inferred.
-
-    :rtype: str or ``NoneType``
-    :returns: App Engine application ID if running in App Engine,
-              else ``None``.
-    """
-    if app_identity is None:
-        return None
-
-    return app_identity.get_application_id()
-
-
-def _file_project_id():
-    """Gets the project ID from the credentials file if one is available.
-
-    :rtype: str or ``NoneType``
-    :returns: Project ID from JSON credentials file if value exists,
-              else ``None``.
-    """
-    credentials_file_path = os.getenv(CREDENTIALS)
-    if credentials_file_path:
-        with open(credentials_file_path, 'rb') as credentials_file:
-            credentials_json = credentials_file.read()
-            credentials = json.loads(credentials_json.decode('utf-8'))
-            return credentials.get('project_id')
-
-
-def _get_nix_config_path():
-    """Get the ``gcloud`` CLI config path on *nix systems.
-
-    :rtype: str
-    :returns: The filename on a *nix system containing the CLI
-              config file.
-    """
-    return os.path.join(_USER_ROOT, '.config', _GCLOUD_CONFIG_FILE)
-
-
-def _get_windows_config_path():
-    """Get the ``gcloud`` CLI config path on Windows systems.
-
-    :rtype: str
-    :returns: The filename on a Windows system containing the CLI
-              config file.
-    """
-    appdata_dir = os.getenv('APPDATA', '')
-    return os.path.join(appdata_dir, _GCLOUD_CONFIG_FILE)
-
-
-def _default_service_project_id():
-    """Retrieves the project ID from the gcloud command line tool.
-
-    This assumes the ``.config`` directory is stored
-    - in ~/.config on *nix systems
-    - in the %APPDATA% directory on Windows systems
-
-    Additionally, the ${HOME} / "~" directory may not be present on Google
-    App Engine, so this may be conditionally ignored.
-
-    Files that cannot be opened with configparser are silently ignored; this is
-    designed so that you can specify a list of potential configuration file
-    locations.
-
-    :rtype: str or ``NoneType``
-    :returns: Project-ID from default configuration file else ``None``
-    """
-    search_paths = []
-    if _USER_ROOT is not None:
-        search_paths.append(_get_nix_config_path())
-
-    if os.name == 'nt':
-        search_paths.append(_get_windows_config_path())
-
-    config = configparser.RawConfigParser()
-    config.read(search_paths)
-
-    if config.has_section(_GCLOUD_CONFIG_SECTION):
-        try:
-            return config.get(_GCLOUD_CONFIG_SECTION, _GCLOUD_CONFIG_KEY)
-        except configparser.NoOptionError:
-            return None
-
-
-def _compute_engine_id():
-    """Gets the Compute Engine project ID if it can be inferred.
-
-    Uses 169.254.169.254 for the metadata server to avoid request
-    latency from DNS lookup.
-
-    See https://cloud.google.com/compute/docs/metadata#metadataserver
-    for information about this IP address. (This IP is also used for
-    Amazon EC2 instances, so the metadata flavor is crucial.)
-
-    See https://github.com/google/oauth2client/issues/93 for context about
-    DNS latency.
-
-    :rtype: str or ``NoneType``
-    :returns: Compute Engine project ID if the metadata service is available,
-              else ``None``.
-    """
-    host = '169.254.169.254'
-    uri_path = '/computeMetadata/v1/project/project-id'
-    headers = {'Metadata-Flavor': 'Google'}
-    connection = http_client.HTTPConnection(host, timeout=0.1)
-
-    try:
-        connection.request('GET', uri_path, headers=headers)
-        response = connection.getresponse()
-        if response.status == 200:
-            return response.read()
-    except socket.error:  # socket.timeout or socket.error(64, 'Host is down')
-        pass
-    finally:
-        connection.close()
-
-
-def _get_production_project():
-    """Gets the production project if it can be inferred."""
-    return os.getenv(PROJECT)
-
-
 def _determine_default_project(project=None):
     """Determine default project ID explicitly or implicitly as fall-back.
 
-    In implicit case, supports three environments. In order of precedence, the
-    implicit environments are:
-
-    * GOOGLE_CLOUD_PROJECT environment variable
-    * GOOGLE_APPLICATION_CREDENTIALS JSON file
-    * Get default service project from
-      ``$ gcloud beta auth application-default login``
-    * Google App Engine application ID
-    * Google Compute Engine project ID (from metadata server)
+    See :func:`google.auth.default` for details on how the default project
+    is determined.
 
     :type project: str
     :param project: Optional. The project name to use as default.
@@ -309,20 +178,7 @@ def _determine_default_project(project=None):
     :returns: Default project if it can be determined.
     """
     if project is None:
-        project = _get_production_project()
-
-    if project is None:
-        project = _file_project_id()
-
-    if project is None:
-        project = _default_service_project_id()
-
-    if project is None:
-        project = _app_engine_id()
-
-    if project is None:
-        project = _compute_engine_id()
-
+        _, project = google.auth.default()
     return project
 
 
@@ -394,6 +250,19 @@ def _date_from_iso8601_date(value):
     return datetime.datetime.strptime(value, '%Y-%m-%d').date()
 
 
+def _time_from_iso8601_time_naive(value):
+    """Convert a zoneless ISO8601 time string to naive datetime time
+
+    :type value: str
+    :param value: The time string to convert
+
+    :rtype: :class:`datetime.time`
+    :returns: A datetime time object created from the string
+
+    """
+    return datetime.datetime.strptime(value, '%H:%M:%S').time()
+
+
 def _rfc3339_to_datetime(dt_str):
     """Convert a microsecond-precision timetamp to a native datetime.
 
@@ -556,6 +425,52 @@ def _datetime_to_pb_timestamp(when):
     return timestamp_pb2.Timestamp(seconds=seconds, nanos=nanos)
 
 
+def _timedelta_to_duration_pb(timedelta_val):
+    """Convert a Python timedelta object to a duration protobuf.
+
+    .. note::
+
+        The Python timedelta has a granularity of microseconds while
+        the protobuf duration type has a duration of nanoseconds.
+
+    :type timedelta_val: :class:`datetime.timedelta`
+    :param timedelta_val: A timedelta object.
+
+    :rtype: :class:`google.protobuf.duration_pb2.Duration`
+    :returns: A duration object equivalent to the time delta.
+    """
+    seconds_decimal = timedelta_val.total_seconds()
+    # Truncate the parts other than the integer.
+    seconds = int(seconds_decimal)
+    if seconds_decimal < 0:
+        signed_micros = timedelta_val.microseconds - 10**6
+    else:
+        signed_micros = timedelta_val.microseconds
+    # Convert nanoseconds to microseconds.
+    nanos = 1000 * signed_micros
+    return duration_pb2.Duration(seconds=seconds, nanos=nanos)
+
+
+def _duration_pb_to_timedelta(duration_pb):
+    """Convert a duration protobuf to a Python timedelta object.
+
+    .. note::
+
+        The Python timedelta has a granularity of microseconds while
+        the protobuf duration type has a duration of nanoseconds.
+
+    :type duration_pb: :class:`google.protobuf.duration_pb2.Duration`
+    :param duration_pb: A protobuf duration object.
+
+    :rtype: :class:`datetime.timedelta`
+    :returns: The converted timedelta object.
+    """
+    return datetime.timedelta(
+        seconds=duration_pb.seconds,
+        microseconds=(duration_pb.nanos / 1000.0),
+    )
+
+
 def _name_from_project_path(path, project, template):
     """Validate a URI path and get the leaf object's name.
 
@@ -597,40 +512,12 @@ def _name_from_project_path(path, project, template):
     return match.group('name')
 
 
-class MetadataPlugin(object):
-    """Callable class to transform metadata for gRPC requests.
-
-    :type credentials: :class:`oauth2client.client.OAuth2Credentials`
-    :param credentials: The OAuth2 Credentials to use for creating
-                        access tokens.
-    """
-
-    def __init__(self, credentials):
-        self._credentials = credentials
-
-    def __call__(self, unused_context, callback):
-        """Adds authorization header to request metadata.
-
-        :type unused_context: object
-        :param unused_context: A gRPC context which is not needed
-                               to modify headers.
-
-        :type callback: callable
-        :param callback: A callback which will use the headers.
-        """
-        access_token = self._credentials.get_access_token().access_token
-        headers = [
-            ('authorization', 'Bearer ' + access_token),
-        ]
-        callback(headers, None)
-
-
-def make_secure_channel(credentials, user_agent, host):
+def make_secure_channel(credentials, user_agent, host, extra_options=()):
     """Makes a secure channel for an RPC service.
 
     Uses / depends on gRPC.
 
-    :type credentials: :class:`oauth2client.client.OAuth2Credentials`
+    :type credentials: :class:`google.auth.credentials.Credentials`
     :param credentials: The OAuth2 Credentials to use for creating
                         access tokens.
 
@@ -640,31 +527,32 @@ def make_secure_channel(credentials, user_agent, host):
     :type host: str
     :param host: The host for the service.
 
+    :type extra_options: tuple
+    :param extra_options: (Optional) Extra gRPC options used when creating the
+                          channel.
+
     :rtype: :class:`grpc._channel.Channel`
     :returns: gRPC secure channel with credentials attached.
     """
-    # ssl_channel_credentials() loads root certificates from
-    # `grpc/_adapter/credentials/roots.pem`.
-    transport_creds = grpc.ssl_channel_credentials()
-    custom_metadata_plugin = MetadataPlugin(credentials)
-    auth_creds = grpc.metadata_call_credentials(
-        custom_metadata_plugin, name='google_creds')
-    channel_creds = grpc.composite_channel_credentials(
-        transport_creds, auth_creds)
     target = '%s:%d' % (host, http_client.HTTPS_PORT)
-    channel_args = (
-        ('grpc.primary_user_agent', user_agent),
-    )
-    return grpc.secure_channel(target, channel_creds,
-                               options=channel_args)
+    http_request = google_auth_httplib2.Request(http=httplib2.Http())
+
+    user_agent_option = ('grpc.primary_user_agent', user_agent)
+    options = (user_agent_option,) + extra_options
+    return google.auth.transport.grpc.secure_authorized_channel(
+        credentials,
+        http_request,
+        target,
+        options=options)
 
 
-def make_secure_stub(credentials, user_agent, stub_class, host):
+def make_secure_stub(credentials, user_agent, stub_class, host,
+                     extra_options=()):
     """Makes a secure stub for an RPC service.
 
     Uses / depends on gRPC.
 
-    :type credentials: :class:`oauth2client.client.OAuth2Credentials`
+    :type credentials: :class:`google.auth.credentials.Credentials`
     :param credentials: The OAuth2 Credentials to use for creating
                         access tokens.
 
@@ -677,10 +565,15 @@ def make_secure_stub(credentials, user_agent, stub_class, host):
     :type host: str
     :param host: The host for the service.
 
+    :type extra_options: tuple
+    :param extra_options: (Optional) Extra gRPC options passed when creating
+                          the channel.
+
     :rtype: object, instance of ``stub_class``
     :returns: The stub object used to make gRPC requests to a given API.
     """
-    channel = make_secure_channel(credentials, user_agent, host)
+    channel = make_secure_channel(credentials, user_agent, host,
+                                  extra_options=extra_options)
     return stub_class(channel)
 
 
