@@ -14,14 +14,22 @@
 
 """Base classes for client used to interact with Google Cloud APIs."""
 
-from oauth2client.service_account import ServiceAccountCredentials
+import google.auth.credentials
+from google.oauth2 import service_account
+import google_auth_httplib2
 import six
 
 from google.cloud._helpers import _determine_default_project
-from google.cloud._http import Connection
 from google.cloud.credentials import get_credentials
 
 
+_GOOGLE_AUTH_CREDENTIALS_HELP = (
+    'This library only supports credentials from google-auth-library-python. '
+    'See https://google-cloud-python.readthedocs.io/en/latest/'
+    'google-cloud-auth.html for help on authentication with this library.'
+)
+
+
 class _ClientFactoryMixin(object):
     """Mixin to allow factories that create credentials.
 
@@ -55,73 +63,80 @@ class _ClientFactoryMixin(object):
         """
         if 'credentials' in kwargs:
             raise TypeError('credentials must not be in keyword arguments')
-        credentials = ServiceAccountCredentials.from_json_keyfile_name(
+        credentials = service_account.Credentials.from_service_account_file(
             json_credentials_path)
         kwargs['credentials'] = credentials
         return cls(*args, **kwargs)
 
-    @classmethod
-    def from_service_account_p12(cls, client_email, private_key_path,
-                                 *args, **kwargs):
-        """Factory to retrieve P12 credentials while creating client.
-
-        .. note::
-          Unless you have an explicit reason to use a PKCS12 key for your
-          service account, we recommend using a JSON key.
-
-        :type client_email: str
-        :param client_email: The e-mail attached to the service account.
-
-        :type private_key_path: str
-        :param private_key_path: The path to a private key file (this file was
-                                 given to you when you created the service
-                                 account). This file must be in P12 format.
-
-        :type args: tuple
-        :param args: Remaining positional arguments to pass to constructor.
-
-        :type kwargs: dict
-        :param kwargs: Remaining keyword arguments to pass to constructor.
-
-        :rtype: :class:`google.cloud.client.Client`
-        :returns: The client created with the retrieved P12 credentials.
-        :raises: :class:`TypeError` if there is a conflict with the kwargs
-                 and the credentials created by the factory.
-        """
-        if 'credentials' in kwargs:
-            raise TypeError('credentials must not be in keyword arguments')
-        credentials = ServiceAccountCredentials.from_p12_keyfile(
-            client_email, private_key_path)
-        kwargs['credentials'] = credentials
-        return cls(*args, **kwargs)
-
 
 class Client(_ClientFactoryMixin):
     """Client to bundle configuration needed for API requests.
 
-    Assumes that the associated ``_connection_class`` only accepts
-    ``http`` and ``credentials`` in its constructor.
+    Stores ``credentials`` and ``http`` object so that subclasses
+    can pass them along to a connection class.
 
-    :type credentials: :class:`oauth2client.client.OAuth2Credentials` or
-                       :class:`NoneType`
-    :param credentials: The OAuth2 Credentials to use for the connection
-                        owned by this client. If not passed (and if no ``http``
-                        object is passed), falls back to the default inferred
-                        from the environment.
+    If no value is passed in for ``http``, a :class:`httplib2.Http` object
+    will be created and authorized with the ``credentials``. If not, the
+    ``credentials`` and ``http`` need not be related.
 
-    :type http: :class:`httplib2.Http` or class that defines ``request()``.
-    :param http: An optional HTTP object to make requests. If not passed, an
+    Callers and subclasses may seek to use the private key from
+    ``credentials`` to sign data.
+
+    A custom (non-``httplib2``) HTTP object must have a ``request`` method
+    which accepts the following arguments:
+
+    * ``uri``
+    * ``method``
+    * ``body``
+    * ``headers``
+
+    In addition, ``redirections`` and ``connection_type`` may be used.
+
+    A custom ``http`` object will also need to be able to add a bearer token
+    to API requests and handle token refresh on 401 errors.
+
+    :type credentials: :class:`~google.auth.credentials.Credentials`
+    :param credentials: (Optional) The OAuth2 Credentials to use for this
+                        client. If not passed (and if no ``http`` object is
+                        passed), falls back to the default inferred from the
+                        environment.
+
+    :type http: :class:`~httplib2.Http`
+    :param http: (Optional) HTTP object to make requests. Can be any object
+                 that defines ``request()`` with the same interface as
+                 :meth:`~httplib2.Http.request`. If not passed, an
                  ``http`` object is created that is bound to the
                  ``credentials`` for the current object.
     """
 
-    _connection_class = Connection
+    SCOPE = None
+    """The scopes required for authenticating with a service.
+
+    Needs to be set by subclasses.
+    """
 
     def __init__(self, credentials=None, http=None):
+        if (credentials is not None and
+                not isinstance(
+                    credentials, google.auth.credentials.Credentials)):
+            raise ValueError(_GOOGLE_AUTH_CREDENTIALS_HELP)
         if credentials is None and http is None:
             credentials = get_credentials()
-        self._connection = self._connection_class(
-            credentials=credentials, http=http)
+        self._credentials = google.auth.credentials.with_scopes_if_required(
+            credentials, self.SCOPE)
+        self._http_internal = http
+
+    @property
+    def _http(self):
+        """Getter for object used for HTTP transport.
+
+        :rtype: :class:`~httplib2.Http`
+        :returns: An HTTP object.
+        """
+        if self._http_internal is None:
+            self._http_internal = google_auth_httplib2.AuthorizedHttp(
+                self._credentials)
+        return self._http_internal
 
 
 class _ClientProjectMixin(object):
@@ -154,26 +169,24 @@ class _ClientProjectMixin(object):
         return _determine_default_project(project)
 
 
-class JSONClient(Client, _ClientProjectMixin):
-    """Client for Google JSON-based API.
-
-    Assumes such APIs use the ``project`` and the client needs to store this
-    value.
+class ClientWithProject(Client, _ClientProjectMixin):
+    """Client that also stores a project.
 
     :type project: str
     :param project: the project which the client acts on behalf of. If not
                     passed falls back to the default inferred from the
                     environment.
 
-    :type credentials: :class:`oauth2client.client.OAuth2Credentials` or
-                       :class:`NoneType`
-    :param credentials: The OAuth2 Credentials to use for the connection
-                        owned by this client. If not passed (and if no ``http``
-                        object is passed), falls back to the default inferred
-                        from the environment.
+    :type credentials: :class:`~google.auth.credentials.Credentials`
+    :param credentials: (Optional) The OAuth2 Credentials to use for this
+                        client. If not passed (and if no ``http`` object is
+                        passed), falls back to the default inferred from the
+                        environment.
 
-    :type http: :class:`httplib2.Http` or class that defines ``request()``.
-    :param http: An optional HTTP object to make requests. If not passed, an
+    :type http: :class:`~httplib2.Http`
+    :param http: (Optional) HTTP object to make requests. Can be any object
+                 that defines ``request()`` with the same interface as
+                 :meth:`~httplib2.Http.request`. If not passed, an
                  ``http`` object is created that is bound to the
                  ``credentials`` for the current object.
 
