@@ -14,12 +14,21 @@
 
 import unittest
 
+import mock
+
+
+def _make_credentials():
+    import google.auth.credentials
+
+    return mock.Mock(spec=google.auth.credentials.Credentials)
+
 
 class Test_ClientFactoryMixin(unittest.TestCase):
 
     @staticmethod
     def _get_target_class():
         from google.cloud.client import _ClientFactoryMixin
+
         return _ClientFactoryMixin
 
     def test_virtual(self):
@@ -29,18 +38,10 @@ class Test_ClientFactoryMixin(unittest.TestCase):
 
 class TestClient(unittest.TestCase):
 
-    def setUp(self):
-        KLASS = self._get_target_class()
-        self.original_cnxn_class = KLASS._connection_class
-        KLASS._connection_class = _MockConnection
-
-    def tearDown(self):
-        KLASS = self._get_target_class()
-        KLASS._connection_class = self.original_cnxn_class
-
     @staticmethod
     def _get_target_class():
         from google.cloud.client import Client
+
         return Client
 
     def _make_one(self, *args, **kw):
@@ -50,7 +51,7 @@ class TestClient(unittest.TestCase):
         from google.cloud._testing import _Monkey
         from google.cloud import client
 
-        CREDENTIALS = object()
+        CREDENTIALS = _make_credentials()
         FUNC_CALLS = []
 
         def mock_get_credentials():
@@ -60,76 +61,80 @@ class TestClient(unittest.TestCase):
         with _Monkey(client, get_credentials=mock_get_credentials):
             client_obj = self._make_one()
 
-        self.assertIsInstance(client_obj._connection, _MockConnection)
-        self.assertIs(client_obj._connection.credentials, CREDENTIALS)
+        self.assertIs(client_obj._credentials, CREDENTIALS)
+        self.assertIsNone(client_obj._http_internal)
         self.assertEqual(FUNC_CALLS, ['get_credentials'])
 
     def test_ctor_explicit(self):
-        CREDENTIALS = object()
+        CREDENTIALS = _make_credentials()
         HTTP = object()
         client_obj = self._make_one(credentials=CREDENTIALS, http=HTTP)
 
-        self.assertIsInstance(client_obj._connection, _MockConnection)
-        self.assertIs(client_obj._connection.credentials, CREDENTIALS)
-        self.assertIs(client_obj._connection.http, HTTP)
+        self.assertIs(client_obj._credentials, CREDENTIALS)
+        self.assertIs(client_obj._http_internal, HTTP)
+
+    def test_ctor_bad_credentials(self):
+        CREDENTIALS = object()
+
+        with self.assertRaises(ValueError):
+            self._make_one(credentials=CREDENTIALS)
 
     def test_from_service_account_json(self):
-        from google.cloud._testing import _Monkey
-        from google.cloud import client
-
         KLASS = self._get_target_class()
-        MOCK_FILENAME = 'foo.path'
-        mock_creds = _MockServiceAccountCredentials()
-        with _Monkey(client, ServiceAccountCredentials=mock_creds):
-            client_obj = KLASS.from_service_account_json(MOCK_FILENAME)
 
-        self.assertIs(client_obj._connection.credentials, mock_creds._result)
-        self.assertEqual(mock_creds.json_called, [MOCK_FILENAME])
+        constructor_patch = mock.patch(
+            'google.oauth2.service_account.Credentials.'
+            'from_service_account_file',
+            return_value=_make_credentials())
 
-    def test_from_service_account_json_fail(self):
+        with constructor_patch as constructor:
+            client_obj = KLASS.from_service_account_json(
+                mock.sentinel.filename)
+
+        self.assertIs(
+            client_obj._credentials, constructor.return_value)
+        self.assertIsNone(client_obj._http_internal)
+        constructor.assert_called_once_with(mock.sentinel.filename)
+
+    def test_from_service_account_json_bad_args(self):
         KLASS = self._get_target_class()
-        CREDENTIALS = object()
-        self.assertRaises(TypeError, KLASS.from_service_account_json, None,
-                          credentials=CREDENTIALS)
 
-    def test_from_service_account_p12(self):
-        from google.cloud._testing import _Monkey
-        from google.cloud import client
+        with self.assertRaises(TypeError):
+            KLASS.from_service_account_json(
+                mock.sentinel.filename, credentials=mock.sentinel.credentials)
 
-        KLASS = self._get_target_class()
-        CLIENT_EMAIL = 'phred@example.com'
-        MOCK_FILENAME = 'foo.path'
-        mock_creds = _MockServiceAccountCredentials()
-        with _Monkey(client, ServiceAccountCredentials=mock_creds):
-            client_obj = KLASS.from_service_account_p12(CLIENT_EMAIL,
-                                                        MOCK_FILENAME)
+    def test__http_property_existing(self):
+        credentials = _make_credentials()
+        http = object()
+        client = self._make_one(credentials=credentials, http=http)
+        self.assertIs(client._http_internal, http)
+        self.assertIs(client._http, http)
 
-        self.assertIs(client_obj._connection.credentials, mock_creds._result)
-        self.assertEqual(mock_creds.p12_called,
-                         [(CLIENT_EMAIL, MOCK_FILENAME)])
+    def test__http_property_new(self):
+        credentials = _make_credentials()
+        client = self._make_one(credentials=credentials)
+        self.assertIsNone(client._http_internal)
 
-    def test_from_service_account_p12_fail(self):
-        KLASS = self._get_target_class()
-        CREDENTIALS = object()
-        self.assertRaises(TypeError, KLASS.from_service_account_p12, None,
-                          None, credentials=CREDENTIALS)
+        patch = mock.patch('google_auth_httplib2.AuthorizedHttp',
+                           return_value=mock.sentinel.http)
+        with patch as mocked:
+            self.assertIs(client._http, mock.sentinel.http)
+            # Check the mock.
+            mocked.assert_called_once_with(credentials)
+            self.assertEqual(mocked.call_count, 1)
+            # Make sure the cached value is used on subsequent access.
+            self.assertIs(client._http_internal, mock.sentinel.http)
+            self.assertIs(client._http, mock.sentinel.http)
+            self.assertEqual(mocked.call_count, 1)
 
 
-class TestJSONClient(unittest.TestCase):
-
-    def setUp(self):
-        KLASS = self._get_target_class()
-        self.original_cnxn_class = KLASS._connection_class
-        KLASS._connection_class = _MockConnection
-
-    def tearDown(self):
-        KLASS = self._get_target_class()
-        KLASS._connection_class = self.original_cnxn_class
+class TestClientWithProject(unittest.TestCase):
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.client import JSONClient
-        return JSONClient
+        from google.cloud.client import ClientWithProject
+
+        return ClientWithProject
 
     def _make_one(self, *args, **kw):
         return self._get_target_class()(*args, **kw)
@@ -139,7 +144,7 @@ class TestJSONClient(unittest.TestCase):
         from google.cloud import client
 
         PROJECT = 'PROJECT'
-        CREDENTIALS = object()
+        CREDENTIALS = _make_credentials()
         FUNC_CALLS = []
 
         def mock_determine_proj(project):
@@ -155,8 +160,8 @@ class TestJSONClient(unittest.TestCase):
             client_obj = self._make_one()
 
         self.assertEqual(client_obj.project, PROJECT)
-        self.assertIsInstance(client_obj._connection, _MockConnection)
-        self.assertIs(client_obj._connection.credentials, CREDENTIALS)
+        self.assertIs(client_obj._credentials, CREDENTIALS)
+        self.assertIsNone(client_obj._http_internal)
         self.assertEqual(
             FUNC_CALLS,
             [(None, '_determine_default_project'), 'get_credentials'])
@@ -177,7 +182,7 @@ class TestJSONClient(unittest.TestCase):
         self.assertEqual(FUNC_CALLS, [(None, '_determine_default_project')])
 
     def test_ctor_w_invalid_project(self):
-        CREDENTIALS = object()
+        CREDENTIALS = _make_credentials()
         HTTP = object()
         with self.assertRaises(ValueError):
             self._make_one(project=object(), credentials=CREDENTIALS,
@@ -186,7 +191,7 @@ class TestJSONClient(unittest.TestCase):
     def _explicit_ctor_helper(self, project):
         import six
 
-        CREDENTIALS = object()
+        CREDENTIALS = _make_credentials()
         HTTP = object()
 
         client_obj = self._make_one(project=project, credentials=CREDENTIALS,
@@ -196,9 +201,8 @@ class TestJSONClient(unittest.TestCase):
             self.assertEqual(client_obj.project, project.decode('utf-8'))
         else:
             self.assertEqual(client_obj.project, project)
-        self.assertIsInstance(client_obj._connection, _MockConnection)
-        self.assertIs(client_obj._connection.credentials, CREDENTIALS)
-        self.assertIs(client_obj._connection.http, HTTP)
+        self.assertIs(client_obj._credentials, CREDENTIALS)
+        self.assertIs(client_obj._http_internal, HTTP)
 
     def test_ctor_explicit_bytes(self):
         PROJECT = b'PROJECT'
@@ -207,26 +211,3 @@ class TestJSONClient(unittest.TestCase):
     def test_ctor_explicit_unicode(self):
         PROJECT = u'PROJECT'
         self._explicit_ctor_helper(PROJECT)
-
-
-class _MockConnection(object):
-
-    def __init__(self, credentials=None, http=None):
-        self.credentials = credentials
-        self.http = http
-
-
-class _MockServiceAccountCredentials(object):
-
-    def __init__(self):
-        self.p12_called = []
-        self.json_called = []
-        self._result = object()
-
-    def from_p12_keyfile(self, email, path):
-        self.p12_called.append((email, path))
-        return self._result
-
-    def from_json_keyfile_name(self, path):
-        self.json_called.append(path)
-        return self._result
